=========
KSP Login
=========

KSP Login is a Django_ app intended as an all-in-one solution for
authentication. It is built mostly on top of the fantastic
`python-social-auth`_ library which does most of the heavy lifting.


Features
========

* A complete frontend, just include a few templates and you're good to go.

* Simple management of user-related data.

* Allows both social and traditional username/password authentication.

More features are coming soon (such as user merging etc).

.. _Django: https://djangoproject.com/

.. _python-social-auth: https://github.com/omab/python-social-auth
